mgcp: Remove use of hardwired @mgw from endpoint IDs.

Matching logic in create_response_with_sdp(), we now look for end point ids that use either the supplied local ip or source address.

Signed-off-by: Michael McTernan <mike.mcternan@wavemobile.com>

Index: osmobss/openbsc/openbsc/src/libmgcp/mgcp_protocol.c
===================================================================
--- osmobss.orig/openbsc/openbsc/src/libmgcp/mgcp_protocol.c	2015-08-28 15:57:00.959361642 +0100
+++ osmobss/openbsc/openbsc/src/libmgcp/mgcp_protocol.c	2015-08-28 15:58:23.605661967 +0100
@@ -479,13 +479,17 @@ static struct mgcp_endpoint *find_endpoi
 	if (strncmp(mgcp, "ds/e1", 5) == 0) {
 		return find_e1_endpoint(cfg, mgcp);
 	} else {
+		const char *addr = cfg->local_ip ? : cfg->source_addr;
+
 		gw = strtoul(mgcp, &endptr, 16);
-		if (gw > 0 && gw < cfg->trunk.number_endpoints && strcmp(endptr, "@mgw") == 0)
+		if (gw > 0 && gw < cfg->trunk.number_endpoints &&
+				endptr[0] == '@' && strcmp(endptr + 1, addr) == 0) {
 			return &cfg->trunk.endpoints[gw];
-	}
+		}
 
-	LOGP(DMGCP, LOGL_ERROR, "Not able to find endpoint: '%s'\n", mgcp);
-	return NULL;
+		LOGP(DMGCP, LOGL_ERROR, "Not able to find the endpoint: '%s' %u in range 1-%u@%s\n", mgcp, gw, cfg->trunk.number_endpoints - 1, addr);
+		return NULL;
+	}
 }
 
 /**
